==> nextcloud-app-calendar-1:4.6.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ka_GE.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s მომხმარებელმა გამოაქვეყნა კალენდარი »%s«",
    "Hello," : "გამარჯობა,",
    "We wanted to inform you that %s has published the calendar »%s«." : "გვსურს შეგატყობინოთ, რომ %s მომხმარებელმა გამოაქყვენა კალენდარი »%s«.",
    "Open »%s«" : "გახნსნა »%s«",
    "Cheers!" : "წარმატებები!",
    "Calendar" : "კალენდარი",
    "Confirm" : "დადასტურება",
    "Where:" : "სად:",
    "Today" : "დღეს",
    "Day" : "დღე",
    "Week" : "კვირა",
    "Month" : "თვე",
    "List" : "ჩამონათვალი",
    "Preview" : "წინასწარი ჩვენება",
    "Copy link" : "ბმულის კოპირება",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "New calendar" : "ახალი კალენდარი",
    "Export" : "ექსპორტი",
    "Name" : "სახელი",
    "Deleted" : "გაუქმდა",
    "Restore" : "აღდგენა",
    "Delete permanently" : "სამუდამოდ წაშლა",
    "Share link" : "ბმულის გაზიარება",
    "can edit" : "შეგიძლია შეცვლა",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "Save" : "შენახვა",
    "Filename" : "ფაილის სახელი",
    "Cancel" : "უარყოფა",
    "Automatic" : "ავტომატური",
    "or" : "ან",
    "List view" : "ჩამონათვლისებური ხედი",
    "Actions" : "მოქმედებები",
    "Show week numbers" : "კვირის ნომრების ჩვენება",
    "Location" : "ადგილმდებარეობა",
    "Description" : "აღწერილობა",
    "to" : "ვის",
    "Add" : "დამატება",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sunday" : "კვირა",
    "Update" : "განახლება",
    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
    "Notification" : "შეტყობინება",
    "Email" : "ელ-ფოსტა",
    "Delete file" : "გაუქმდეს ფაილი",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Unknown" : "ამოუცნობი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Tentative" : "საცდელი",
    "Send email" : "ელ-წერილის გაგზავნა",
    "All day" : "მთელი დღე",
    "Repeat" : "გამეორება",
    "never" : "არასდროს",
    "after" : "შემდეგ",
    "available" : "ხელმისაწვდომი",
    "More" : "უფრო მეტი",
    "Global" : "გლობალური",
    "Subscribe" : "გამოწერა",
    "Personal" : "პირადი",
    "Details" : "დეტლაები",
    "Attendees" : "დამსწრეები",
    "Resources" : "რესურსები",
    "Close" : "დახურვა",
    "Anniversary" : "დაბადების დღე",
    "Week {number} of {year}" : "კვირა {number} {year}-დან",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "Other" : "სხვა",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
    "Status" : "სტატუსი",
    "Confirmed" : "დადასტურებლია",
    "Categories" : "კატეგორიები",
    "Talk" : "საუბარი",
    "Mail" : "ფოსტა",
    "Birthday" : "დაბადების დრე"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-calendar-1:5.3.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/ka_GE.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s მომხმარებელმა გამოაქვეყნა კალენდარი »%s«",
    "Hello," : "გამარჯობა,",
    "We wanted to inform you that %s has published the calendar »%s«." : "გვსურს შეგატყობინოთ, რომ %s მომხმარებელმა გამოაქყვენა კალენდარი »%s«.",
    "Open »%s«" : "გახნსნა »%s«",
    "Cheers!" : "წარმატებები!",
    "Calendar" : "კალენდარი",
    "Confirm" : "დადასტურება",
    "Description:" : "აღწერა:",
    "Where:" : "სად:",
    "Today" : "დღეს",
    "Day" : "დღე",
    "Week" : "კვირა",
    "Month" : "თვე",
    "List" : "ჩამონათვალი",
    "Preview" : "წინასწარი ჩვენება",
    "Copy link" : "ბმულის კოპირება",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "New calendar" : "ახალი კალენდარი",
    "Export" : "ექსპორტი",
    "Name" : "სახელი",
    "Deleted" : "გაუქმდა",
    "Restore" : "აღდგენა",
    "Delete permanently" : "სამუდამოდ წაშლა",
    "Deck" : "დასტა",
    "Hidden" : "უჩინარი",
    "Share link" : "ბმულის გაზიარება",
    "can edit" : "შეგიძლია შეცვლა",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "Save" : "შენახვა",
    "Filename" : "ფაილის სახელი",
    "Cancel" : "უარყოფა",
    "Automatic" : "ავტომატური",
    "List view" : "ჩამონათვლისებური ხედი",
    "Actions" : "მოქმედებები",
    "or" : "ან",
    "Show week numbers" : "კვირის ნომრების ჩვენება",
    "Update" : "განახლება",
    "Location" : "ადგილმდებარეობა",
    "Description" : "აღწერილობა",
    "to" : "ვის",
    "Add" : "დამატება",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sunday" : "კვირა",
    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
    "Notification" : "შეტყობინება",
    "Email" : "ელ-ფოსტა",
    "days" : "დღე",
    "weeks" : "კვირა",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Delete file" : "გაუქმდეს ფაილი",
    "Done" : "დასრულდა",
    "Room name" : "ოთახის სახელი",
    "Unknown" : "ამოუცნობი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Tentative" : "საცდელი",
    "Attendees" : "დამსწრეები",
    "Repeat" : "გამეორება",
    "never" : "არასდროს",
    "after" : "შემდეგ",
    "Resources" : "რესურსები",
    "available" : "ხელმისაწვდომი",
    "Global" : "გლობალური",
    "Subscribe" : "გამოწერა",
    "Personal" : "პირადი",
    "Edit event" : "მოვლენის ცვლილება",
    "All day" : "მთელი დღე",
    "Close" : "დახურვა",
    "Anniversary" : "დაბადების დღე",
    "Week {number} of {year}" : "კვირა {number} {year}-დან",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "Other" : "სხვა",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
    "Status" : "სტატუსი",
    "Confirmed" : "დადასტურებლია",
    "Categories" : "კატეგორიები",
    "Details" : "დეტლაები"
},
"nplurals=2; plural=(n!=1);");
